==> opennms-webapp-1.7.3-sources.jar: org/opennms/web/controller/OutageResolvedController.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified 
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 * 
 * Modifications:
 * 
 * 2007 Feb 01: Standardize on successView for the view name and cleanup unused code. - dj@opennms.org
 * 
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *      http://www.opennms.org/
 *      http://www.opennms.com/
 */
package org.opennms.web.controller;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.opennms.web.svclayer.outage.OutageService;
import org.opennms.web.svclayer.outage.OutageTable;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.UrlFilenameViewController;

public class OutageResolvedController extends UrlFilenameViewController {
    
        private String m_successView;

        private OutageService m_outageService ;
        
        private OutageTable m_outageTable = new OutageTable();
        
        public void setOutageService(OutageService service) {
                m_outageService = service;
        }

        
        protected ModelAndView handleRequestInternal(HttpServletRequest request,
                HttpServletResponse reply) {
            
            
          return new ModelAndView(getSuccessView(),
                                  m_outageTable.getResolvedOutageTable(request, reply,m_outageService));
//          return new ModelAndView("displayResolvedOutages" + getSuffix(),
//          m_outageTable.getResolvedOutageTable(request, reply,m_outageService));
            
        }
        
        public void setSuccessView(String successView) {
            m_successView = successView;
        }

        public String getSuccessView() {
            return m_successView;
        }

}

==> opennms-webapp-1.9.6-sources.jar: org/opennms/web/controller/OutageResolvedController.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified 
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 * 
 * Modifications:
 * 
 * 2007 Feb 01: Standardize on successView for the view name and cleanup unused code. - dj@opennms.org
 * 
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *      http://www.opennms.org/
 *      http://www.opennms.com/
 */
package org.opennms.web.controller;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.opennms.web.svclayer.outage.OutageService;
import org.opennms.web.svclayer.outage.OutageTable;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.UrlFilenameViewController;

/**
 * <p>OutageResolvedController class.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public class OutageResolvedController extends UrlFilenameViewController {
    
        private String m_successView;

        private OutageService m_outageService ;
        
        private OutageTable m_outageTable = new OutageTable();
        
        /**
         * <p>setOutageService</p>
         *
         * @param service a {@link org.opennms.web.svclayer.outage.OutageService} object.
         */
        public void setOutageService(OutageService service) {
                m_outageService = service;
        }

        
        /** {@inheritDoc} */
        protected ModelAndView handleRequestInternal(HttpServletRequest request,
                HttpServletResponse reply) {
            
            
          return new ModelAndView(getSuccessView(),
                                  m_outageTable.getResolvedOutageTable(request, reply,m_outageService));
//          return new ModelAndView("displayResolvedOutages" + getSuffix(),
//          m_outageTable.getResolvedOutageTable(request, reply,m_outageService));
            
        }
        
        /**
         * <p>setSuccessView</p>
         *
         * @param successView a {@link java.lang.String} object.
         */
        public void setSuccessView(String successView) {
            m_successView = successView;
        }

        /**
         * <p>getSuccessView</p>
         *
         * @return a {@link java.lang.String} object.
         */
        public String getSuccessView() {
            return m_successView;
        }

}
